<?php

namespace Drupal\quickchat_sync;

use Drupal\quickchat\QuickchatApiClient;

/**
 * Quickchat Sync API client extending QuickchatApiClient base class.
 */
class QuickchatSyncApiClient extends QuickchatApiClient {

  /**
   * API endpoint to fetch, re-train or update a Drupal chatbot model.
   *
   * @param string $action
   *   Action to perform: fetch, retrain, update_name, update_short_description,
   *   update_knowledge_base, update_how_to_reach_you.
   * @param string $scenario_id
   *   ID associated with your Quickchat API implementation.
   *   update_knowledge_base, update_how_to_reach_you.
   * @param string $token
   *   Token to use for API limited access.
   * @param string $text
   *   Optional parameter, only to be provided for update actions.
   *
   * @return array
   *   Json from API response parsed to array format.
   *
   * @see https://www.quickchat.ai/docs/#send-message-to-ai
   */
  public function drupal($action, $scenario_id, $token, $text = NULL) {
    $data = [
      'token' => $token,
      'action' => $action,
      'scenario_id' => $scenario_id,
    ];

    if ($text) {
      $data['text'] = $text;

      if ($action == 'update_knowledge_base') {
        $data['text'] = json_encode(explode('\n', $data['text']));
      }
    }

    return $this->request('POST', '/drupal/', $data);
  }

}
