<?php

namespace Drupal\quickchat\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the module settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'quickchat.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'quickchat_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('quickchat.settings');

    $form['api_baseurl'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API base url'),
      '#required' => TRUE,
      '#description' => $this->t('API base url: https://app.quickchat.com/api'),
      '#default_value' => $config->get('api_baseurl'),
    ];

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#description' => $this->t('Put here your Quickchat API key. Get it from https://app.quickchat.com/api.'),
      '#default_value' => $config->get('api_key'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configFactory->getEditable('quickchat.settings')
      ->set('api_key', $values['api_key'])
      ->set('api_baseurl', $values['api_baseurl'])
      ->save();

    parent::submitForm($form, $form_state);
  }

}
